@@ -115,8 +115,7 @@ aSPUs <- function(Zs, corSNP, pow = c(1:8, Inf), n.perm = 1000, Ps = FALSE, prun
                 T0s[b] = round(max(abs(U0)), digits = 8)
             }
         }
-        pPerm0[j] = round(sum(abs(Ts[j]) <= abs(T0s))/n.perm,
-            digits = 8)
+        pPerm0[j] = sum(abs(Ts[j]) <= abs(T0s))/n.perm
         P0s = ((n.perm - rank(abs(T0s))) + 1)/(n.perm)
         if (j == 1)
             minp0 = P0s
